#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-64eb21bb3d73057703a5a6cf47edf0b3
key: kanex_KRwZcydBfSb9TdReDMMyi8
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-KRwZcydBfSb9TdReDMMyi8
depends:
    adjunctions-4.3-e46cf12f2e7e306822764e6eb775fdd9
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-a91321d086a2de4a04a44d60c347669e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
